# utibat

https://pypi.org/project/utibat/

`utibat` is a simple command-line tool for displaying battery percentage.
## Features

- Display the current battery percentage.
- Show a progress bar representing the battery level.
- Colored output to indicate different battery levels.

## Example Output
```sh
Battery Percentage:  57%
[##########----------]
```

## Installation

You can install `utibat` via pip:

```sh
pip install utibat
```

## Usage
```sh
utibat battery
```
This will display the current battery percentage along with a progress bar.

## License
This project is licensed under the MIT License - see the LICENSE file for details.

